# Api Framework Package

This is an extremely simple package that is meant to be a 
[pydantic](https://pydantic-docs.helpmanual.io/) implementation
for a basic RESTful API interaction client. This includes both sync and async usages.

## Installation
Synchronous implementation - if you aren't sure, you probably want this:
```
python -m pip install arya-api-framework[sync]
```
Asynchronous implementation:
```
python -m pip install arya-api-framework[async]
```

----
### Note
This may be documented properly in the future, but I don't really see a reason for that
right now, given that I am only creating for specific usages.